@@ -44,10 +44,6 @@ class NonBlockingBOSH(NonBlockingTransport):
             idlequeue, estabilish_tls, certs, tls_version, cipher_list)
 
         self.bosh_sid = None
-        if locale.getdefaultlocale()[0]:
-            self.bosh_xml_lang = locale.getdefaultlocale()[0].split('_')[0]
-        else:
-            self.bosh_xml_lang = 'en'
 
         self.http_version = 'HTTP/1.1'
         self.http_persistent = True
@@ -416,7 +412,7 @@ class NonBlockingBOSH(NonBlockingTransport):
             t = BOSHBody(
                     attrs={ 'to': self.bosh_to,
                             'sid': self.bosh_sid,
-                            'xml:lang': self.bosh_xml_lang,
+                            'xml:lang': self._owner.lang,
                             'xmpp:restart': 'true',
                             'secure': self.bosh_secure,
                             'xmlns:xmpp': 'urn:xmpp:xbosh'})
@@ -427,7 +423,7 @@ class NonBlockingBOSH(NonBlockingTransport):
                     'route': 'xmpp:%s:%s' % (self.route_host, self.route_port),
                     'to': self.bosh_to,
                     'wait': str(self.bosh_wait),
-                    'xml:lang': self.bosh_xml_lang,
+                    'xml:lang': self._owner.lang,
                     'xmpp:version': '1.0',
                     'ver': '1.6',
                     'xmlns:xmpp': 'urn:xmpp:xbosh'})
